@@ -105,24 +105,35 @@ def vstructures(dag):
 
 
 # add missing value in dataset
-def add_missing(data, cause_dict):
+def add_missing(data, cause_dict, m_min=0.1, m_max=0.6):
     data_missing = deepcopy(data)
-    m_min = 0.1
-    m_max = 0.6
     for var in cause_dict.keys():
+        m = np.random.uniform(m_min, m_max)
         if len(cause_dict[var]) == 0:
-            m = np.random.uniform(m_min, m_max)
             data_missing[var][np.random.uniform(size=len(data)) < m] = None
         else:
             for cause in cause_dict[var]:
                 if data[cause].dtype == 'category':
-                    state_m = data[cause].mode()[0]
-                    data_missing[var][(np.random.uniform(size=len(data)) < m_max) & (data[cause] == state_m)] = None
-                    data_missing[var][(np.random.uniform(size=len(data)) < m_min) & (data[cause] != state_m)] = None
+                    states = list(data[cause].unique())
+                    selected_state = []
+                    while True:
+                        state_single = random.choice(states)
+                        selected_state.append(state_single)
+                        states.remove(state_single)
+                        if data[cause].value_counts()[selected_state].sum() > m * data.shape[0]:
+                            m_h = np.random.uniform(m, m * data.shape[0] / data[cause].isin(selected_state).sum())
+                            m_l = (data.shape[0] * m - data[cause].isin(selected_state).sum() * m_h) / data[cause].isin(
+                                states).sum()
+                            break
+                    data_missing[var][
+                        (np.random.uniform(size=len(data)) < m_h) & (data[cause].isin(selected_state))] = None
+                    data_missing[var][(np.random.uniform(size=len(data)) < m_l) & (data[cause].isin(states))] = None
                 elif data[cause].dtype == 'float' or data[cause].dtype == 'int':
-                    thres = data[cause].quantile(0.2)
-                    data_missing[var][(np.random.uniform(size=len(data)) < m_max) & (data[cause] < thres)] = None
-                    data_missing[var][(np.random.uniform(size=len(data)) < m_min) & (data[cause] >= thres)] = None
+                    m_h = np.random.uniform(m, 1)
+                    thres = data[cause].quantile(m)
+                    data_missing[var][(np.random.uniform(size=len(data)) < m_h) & (data[cause] < thres)] = None
+                    data_missing[var][
+                        (np.random.uniform(size=len(data)) < (1 - m_h) / (1 - m) * m) & (data[cause] >= thres)] = None
                 else:
                     raise Exception('data type ' + data[cause].dtype + ' is not supported.')
     return data_missing
