@@ -78,13 +78,13 @@ def bic_counter(data, arities, cols, weight=None):
     return bic
 
 
-def nal(data, cols, alpha=0.3):
+def nal(data, cols, alpha=0.3, mul=1):
     arities = np.amax(data, axis=0) + 1
     data_local = np.delete(data, data[:, cols].min(axis=1) < 0, axis=0)
     if data_local.shape[0] == 0:
         return -np.inf
     else:
-        return nal_counter(data_local, arities, cols, alpha)
+        return nal_counter(data_local, arities, cols, alpha, mul)
 
 
 def nal_sev(data, cols, cols_rvs):
@@ -94,7 +94,7 @@ def nal_sev(data, cols, cols_rvs):
 
 
 @njit(fastmath=True)
-def nal_counter(data, arities, cols, alpha=0.3):
+def nal_counter(data, arities, cols, alpha=0.3, mul=1):
     strides = np.empty(len(cols), dtype=np.uint32)
     idx = len(cols) - 1
     stride = 1
@@ -128,7 +128,7 @@ def nal_counter(data, arities, cols, alpha=0.3):
     if alpha == 1:
         nal -= 0.5 * np.log(data.shape[0]) / data.shape[0] * (arities[cols[0]] - 1) * strides[0]
     else:
-        nal -= 1 / data.shape[1] * np.power(data.shape[0], -alpha) * (arities[cols[0]] - 1) * strides[0]
+        nal -= mul / data.shape[1] * np.power(data.shape[0], -alpha) * (arities[cols[0]] - 1) * strides[0]
     return nal
 
 
@@ -196,12 +196,14 @@ def density_counter(data, arities):
     return CT
 
 
-def local_score(data, cols, score_function='default', weights=None, alpha=0.3):
+def local_score(data, cols, score_function='default', weights=None, alpha=0.3, mul=1):
     '''
     :param weights: weight for data
     :param data: numbered version of data set
     :param cols: the index of node and its parents, the first element represents the index of the node and the following elements represent the indices of its parents
     :param score_function: name of score function, currently support bic, nal, bic_g
+    :param alpha: alpha parameter for NAL score
+    :param mul: multiplicator used for NAL score
     :return: local score of node (cols[0]) given its parents (cols[1:])
     '''
     if len(data) == 0:
@@ -210,7 +212,7 @@ def local_score(data, cols, score_function='default', weights=None, alpha=0.3):
         if score_function == 'default':
             score_function = 'bic' if 'int' in data.dtype.name else 'bic_g'
         if score_function in ['nal', 'nal_g']:
-            ls = globals()[score_function](data, np.asarray(cols), alpha)
+            ls = globals()[score_function](data, np.asarray(cols), alpha, mul)
         else:
             try:
                 ls = globals()[score_function](data, np.asarray(cols), weights)
